@@ -1,8 +1,7 @@
 import asyncio
-from typing import Dict, List, Optional
-
-from discord import Embed, Emoji, Forbidden, Message, Reaction
+from typing import Dict, List, Optional, Union, Sequence
 
+from discord import Embed, Emoji, Forbidden, Message
 from discordmenu.embed.control import EmbedControl
 from discordmenu.emoji.emoji_cache import emoji_cache
 
@@ -30,7 +29,8 @@ async def remove_reaction(message: Message, emoji, user_id):
     member = message.guild.get_member(user_id)
 
     try:
-        await message.remove_reaction(emoji, member)
+        # support custom emojis
+        await message.remove_reaction(emoji_cache.get_emoji(emoji), member)
     except Forbidden:
         pass
 
@@ -72,9 +72,25 @@ def diff_emojis(message: Message, next_embed_control: Optional["EmbedControl"]):
     return diff_emojis_raw(current_emojis, next_emojis)
 
 
-def diff_emojis_raw(current_emojis: List[Reaction], next_emojis: List[Reaction]):
+def diff_emojis_raw(current_emojis: List[Union[str, Emoji]],
+                    next_emojis: List[Union[str, Emoji]]):
+    add = sorted(
+        set(e for e in next_emojis if e and not emoji_matches(e, current_emojis)),
+        key=lambda x: next_emojis.index(x))
+    remove = list(set(e for e in current_emojis if e and not emoji_matches(e, next_emojis)))
     return {
-        'add': sorted(set(
-            e for e in next_emojis if e and e not in current_emojis), key=lambda x: next_emojis.index(x)),
-        'remove': list(set(e for e in current_emojis if e and e not in next_emojis)),
+        'add': [emoji_cache.get_by_name(e) for e in add],
+        'remove': remove,
     }
+
+
+def emoji_matches(emoji: Union[str, Emoji, Sequence[Union[str, Emoji]]],
+                  emoji_to_match: List[Union[str, Emoji]]) -> bool:
+    if isinstance(emoji, tuple) or isinstance(emoji, list):
+        # handle case of fallback emojis
+        return any(emoji_matches(e, emoji_to_match) for e in emoji)
+    # handle case of custom emojis as well as normal unicode emojis
+    if isinstance(emoji, Emoji):
+        emoji = emoji.name
+    emoji_to_match = [e.name if isinstance(e, Emoji) else e for e in emoji_to_match]
+    return emoji in emoji_to_match
