@@ -3,13 +3,13 @@ from typing import Callable, List, Optional, Coroutine, Dict
 
 import discord
 from discord import Message, RawReactionActionEvent
+
 from discordmenu.discord_client import remove_reaction, update_embed_control, send_embed_control, \
     diff_emojis_raw
 from discordmenu.embed.control import EmbedControl
 from discordmenu.embed.emoji import DEFAULT_EMBED_MENU_EMOJI_CONFIG, EmbedMenuEmojiConfig
 from discordmenu.embed.view_state import ViewState
 from discordmenu.emoji.emoji import discord_emoji_to_emoji_name
-from discordmenu.emoji.emoji_cache import emoji_cache
 from discordmenu.reaction_filter import ReactionFilter
 
 _IntraMessageState = Dict
@@ -18,7 +18,6 @@ NextEmbedControlFunc = Callable[[Optional[Message], Dict, _IntraMessageState], C
 
 class EmbedMenu:
     def __init__(self,
-                 reaction_filters: List[ReactionFilter],
                  transitions: Dict[str, NextEmbedControlFunc],
                  initial_pane: Callable,
                  emoji_config: EmbedMenuEmojiConfig = DEFAULT_EMBED_MENU_EMOJI_CONFIG,
@@ -27,7 +26,6 @@ class EmbedMenu:
                  ):
         self.emoji_config = emoji_config
         self.transitions = transitions
-        self.reaction_filters = reaction_filters
         self.initial_pane = initial_pane
         self.unsupported_transition_announce_timeout = unsupported_transition_announce_timeout
         self.delete_func = delete_func
@@ -37,8 +35,8 @@ class EmbedMenu:
         e_buttons = embed_control.emoji_buttons
 
         # Only add the close button if it doesn't exist, in case user has overridden it.
-        e_buttons.append(
-            self.emoji_config.delete_message) if self.emoji_config.delete_message not in e_buttons else None
+        if self.emoji_config.delete_message not in e_buttons:
+            e_buttons.insert(0, self.emoji_config.delete_message)
         return await send_embed_control(ctx, embed_control, message=message)
 
     async def transition(self, message, ims, emoji_clicked, member, **data):
@@ -67,7 +65,7 @@ class EmbedMenu:
             new_control = await transition_func(message, ims, **data)
         if new_control is not None:
             current_emojis = [e.emoji for e in message.reactions]
-            next_emojis = new_control.emoji_buttons + [emoji_cache.get_emoji(self.emoji_config.delete_message)]
+            next_emojis = [self.emoji_config.delete_message] + new_control.emoji_buttons
 
             emoji_diff = diff_emojis_raw(current_emojis, next_emojis)
             await update_embed_control(message, new_control, emoji_diff)
@@ -83,15 +81,15 @@ class EmbedMenu:
         await asyncio.sleep(self.unsupported_transition_announce_timeout)
         await message.clear_reaction(self.emoji_config.unsupported_transition)
 
-    async def should_respond_raw(self, message, event: RawReactionActionEvent):
-        for reaction_filter in self.reaction_filters:
+    async def should_respond_raw(self, message, event: RawReactionActionEvent, reaction_filters: List[ReactionFilter]):
+        for reaction_filter in reaction_filters:
             allow = await reaction_filter.allow_reaction_raw(message, event)
             if not allow:
                 return False
         return True
 
-    async def should_respond(self, message, reaction, member):
-        for reaction_filter in self.reaction_filters:
+    async def should_respond(self, message, reaction, reaction_filters: List[ReactionFilter], member):
+        for reaction_filter in reaction_filters:
             allow = await reaction_filter.allow_reaction(message, reaction, member)
             if not allow:
                 return False
